A Python library and CLI for leveraging the Pending AI Drug Discovery and Cheminformatics Platform enabled by scalable artificial intelligence and quantum mechanics.

## Getting Started

You can install this  for compatible Python versions `>=3.9`.

```sh
pip install pendingai
```

## Setting up an Account

Access to the Pending AI Platform requires a registered account. Reach out to our team via email at `contact@pending.ai` or visit our documentation pages here:

- [https://docs.pending.ai](https://docs.pending.ai)
- [https://pending.ai](https://pending.ai)

The first link provides an overview of the different services offered by the Pending AI Platform and the binded API leveraged for this library and CLI. The second link is the Pending AI company page providing a way to express interest in the different services.

Our work is constantly evolving and welcoming feedback of any sort! Reach out to us by email at `support@pending.ai` to notify about any issues or for more help with onbording with the platform.

## Acknowledgements

The library included the [cytoscape.js](https://github.com/cytoscape/cytoscape.js) library for rendering images, which is distributed under the MIT license. The original license text is provided below:

> Copyright (c) 2016-2024, The Cytoscape Consortium.
>
> Permission is hereby granted, free of charge, to any person obtaining a copy of
> this software and associated documentation files (the "Software"), to deal in
> the Software without restriction, including without limitation the rights to
> use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
> of the Software, and to permit persons to whom the Software is furnished to do
> so, subject to the following conditions:
>
> The above copyright notice and this permission notice shall be included in all
> copies or substantial portions of the Software.
>
> THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
> IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
> FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
> AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
> LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
> OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
> SOFTWARE.
